@@ -1,26 +1,29 @@
 
 
+from zoom import __version__
 from zoom.mvc import View
 from zoom.page import page
 from zoom.tools import load_content
 from zoom.browse import browse
-from zoom.fields import *
+import zoom.fields as f
 from zoom.validators import required
 
-my_form = Fields(
-    Section('Personal', [
-        TextField('Name', required, size=20, value='John Doe', hint='this is a hint'),
-        MemoField('Notes', hint='this is a hint'),
+import widgets
+
+my_form = f.Fields(
+    f.Section('Personal', [
+        f.TextField('Name', required, size=20, value='John Doe', hint='this is a hint'),
+        f.MemoField('Notes', hint='this is a hint'),
         ]),
-    Section('Social', [
-        TextField('Twitter', size=15, value='jdoe', hint='optional'),
+    f.Section('Social', [
+        f.TextField('Twitter', size=15, value='jdoe', hint='optional'),
         ]),
-    ButtonField('Save'),
+    f.ButtonField('Save'),
     )
 
-small_form = Fields(
-    TextField("Name", size=20),
-    TextField("Address"),
+small_form = f.Fields(
+    f.TextField("Name", size=20),
+    f.TextField("Address"),
 )
 
 class MyView(View):
@@ -31,7 +34,8 @@ class MyView(View):
         db = site.db
 
         cmd = 'select id, username, email, phone from users limit 10'
-        data = browse(db(cmd)) + '<br>or in sortable form:' + browse(db(cmd), sortable=True)
+        data = browse(db(cmd)) + \
+            '<br>or in sortable form:' + browse(db(cmd), sortable=True)
 
         content = load_content(
             'sample.md',
@@ -43,8 +47,11 @@ class MyView(View):
         )
         return page(content)
 
+    def widgets(self):
+        return widgets.view()
+
     def about(self):
-        return page(load_content('about.md'))
+        return load_content('about.md', version=__version__)
 
 
 def main(route, request):
