@@ -21,6 +21,7 @@ from zoom.utils import existing
 from zoom.users import Users
 from zoom.background import load_app_background_jobs
 
+
 DEFAULT_SYSTEM_APPS = ['register', 'profile', 'settings', 'login', 'logout']
 DEFAULT_MAIN_APPS = ['home', 'admin', 'apps']
 DEFAULT_SETTINGS = dict(
@@ -401,13 +402,14 @@ def respond(content, request):
     """construct a response"""
 
     html_response = zoom.response.HTMLResponse
+    json_response = zoom.response.JSONResponse
 
     if content:
         if isinstance(content, zoom.response.Response):
             result = content
 
-        elif isinstance(content, zoom.Component):
-            result = html_response(content.render())
+        elif isinstance(content, (str, zoom.Component)):
+            result = zoom.Page(content).render(request)
 
         elif hasattr(content, 'render') and content.render:
             result = content.render(request)
@@ -415,8 +417,8 @@ def respond(content, request):
         elif isinstance(content, (list, set, tuple)):
             result = html_response(''.join(content))
 
-        elif isinstance(content, str):
-            result = html_response(content)
+        elif isinstance(content, (dict, )):
+            result = json_response(content)
 
         else:
             result = html_response('OK')
@@ -753,3 +755,7 @@ def handler(request, next_handler, *rest):
     else:
         logger.debug('app responded with type %s', type(response))
     return response or next_handler(request, *rest)
+
+def get_app():
+    """Return the current app"""
+    return zoom.system.request.app
