@@ -1599,7 +1599,7 @@ class DateField(Field):
     representations of those dates formatted according to the specified
     format.
 
-    >>> DateField("Start Date").widget()
+    >>> str(DateField("Start Date").widget())
     '<input class="date_field" type="text" id="start_date" maxlength="12" name="start_date" value="" />'
 
     >>> from datetime import date, datetime
@@ -1648,7 +1648,7 @@ class DateField(Field):
     >>> failed
     True
 
-    >>> DateField("Start Date", value=date(2015,1,1)).widget()
+    >>> str(DateField("Start Date", value=date(2015,1,1)).widget())
     '<input class="date_field" type="text" id="start_date" maxlength="12" name="start_date" value="Jan 01, 2015" />'
 
     """
@@ -1671,18 +1671,19 @@ class DateField(Field):
 
     def display_value(self, alt_format=None):
         # pylint: disable=E1101
-        format = alt_format or self.format
+        display_format = alt_format or self.format
         if self.value:
             strftime = datetime.datetime.strftime
             try:
-                result = strftime(self.evaluate()[self.name], format)
+                result = strftime(self.evaluate()[self.name], display_format)
             except ValueError:
                 result = self.value
         else:
-            result = self.default and self.default.strftime(format) or ''
+            result = self.default and self.default.strftime(display_format) or ''
         return result
 
     def widget(self):
+        zoom.requires('jquery-ui')
         value = self.display_value(self.input_format)
         parameters = dict(
             name=self.name,
@@ -1693,20 +1694,26 @@ class DateField(Field):
             Class=self.css_class,
         )
         js = []
+        js.append("""
+            $('.date_field').datepicker({
+                dateFormat: 'M d, yy',
+                changeMonth: true,
+                changeYear: true
+            })
+        """)
         if self.min != None:
             js.append("""
-            $(function(){
-                $('#%s').datepicker('option', 'minDate', '%s');
-            });
+            $('#%s').datepicker('option', 'minDate', '%s');
             """ % (self.id, self.min.strftime(self.input_format)))
 
         if self.max != None:
             js.append("""
-            $(function(){
-                $('#%s').datepicker('option', 'maxDate', '%s');
-            });
+            $('#%s').datepicker('option', 'maxDate', '%s');
             """ % (self.id, self.max.strftime(self.input_format)))
-        return html.tag('input', **parameters)
+        return zoom.Component(
+            html.tag('input', **parameters),
+            js=js,
+        )
 
     def show(self):
         return self.visible and bool(self.value) and self.layout(self.label, self.display_value()) or ''
@@ -1752,6 +1759,19 @@ class BirthdateField(DateField):
     size = maxlength = 12
     css_class = 'birthdate_field'
 
+    def widget(self):
+        return zoom.Component(
+            DateField.widget(self),
+            js = """
+                $('.birthdate_field')
+                    .datepicker({
+                        dateFormat: 'M d, yy',
+                        changeMonth: true,
+                        changeYear: true,
+                        yearRange: '-120:+00'
+                    });
+            """
+        )
 
 class CheckboxesField(Field):
     """Checkboxes field.
@@ -2193,7 +2213,7 @@ class PulldownField(TextField):
         found = False
         result.append(self.select_layout.format(**dict(place=self.placeholder, classed=self.css_class, name=name)))
         for option in self.options:
-            if type(option) in (list, tuple) and len(option)==2:
+            if type(option) in (list, tuple) and len(option) == 2:
                 label, value = option
             else:
                 label, value = option, option
@@ -2211,10 +2231,12 @@ class PulldownField(TextField):
 
 class ChosenSelectField(PulldownField):
     css_class = 'chosen'
-    libs = ['/static/zoom/chosen/chosen.jquery.js']
-    styles = ['/static/zoom/chosen/chosen.css']
     select_layout = '<select data-placeholder="{place}" class="{classed}" name="{name}" id="{name}">\n'
 
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        zoom.requires('chosen')
+
 
 class MultiselectField(TextField):
     """Multiselect Field
@@ -2507,8 +2529,7 @@ class ChosenMultiselectField(MultiselectField):
             self.placeholder = 'Select ' + self.label
 
     def widget(self):
-        libs = ['/static/zoom/chosen/chosen.jquery.js']
-        styles = ['/static/zoom/chosen/chosen.css']
+        zoom.requires('chosen')
         if self.value == None:
             current_values = self.default
         else:
@@ -2528,7 +2549,7 @@ class ChosenMultiselectField(MultiselectField):
             else:
                 result.append('<option %svalue="%s">%s</option>\n' % (style,value,label))
         result.append('</select>')
-        return component(result, libs=libs, styles=styles)
+        return ''.join(result)
 
 
 class RangeSliderField(IntegerField):
