@@ -25,6 +25,9 @@ default_packages = {
         ],
         'styles': [
             '/static/zoom/bootstrap/bootstrap4.5/css/bootstrap.min.css'
+        ],
+        'requires': [
+            'jquery',
         ]
     },
     'd3': {
@@ -43,6 +46,25 @@ default_packages = {
             'd3',
         ]
     },
+    "chartjs": {
+        "libs": [
+            "//cdnjs.cloudflare.com/ajax/libs/Chart.js/2.9.3/Chart.min.js"
+        ],
+        "styles": [
+            "//cdnjs.cloudflare.com/ajax/libs/Chart.js/2.9.3/Chart.min.css"
+        ]
+    },
+    "chosen": {
+        "libs": [
+            "/static/zoom/chosen/chosen.jquery.min.js"
+        ],
+        "styles": [
+            "/static/zoom/chosen/chosen.min.css"
+        ],
+        'requires': [
+            'jquery',
+        ]
+    },
     'cookieconsent': {
         'libs': [
             '/static/zoom/cookieconsent.js',
@@ -184,9 +206,12 @@ def get_registered_packages():
     packages_list = [
         default_packages,
         zoom.system.site.packages,
-        zoom.system.request.app.common_packages,
-        zoom.system.request.app.packages,
     ]
+    if zoom.system.request:
+        packages_list.extend([
+            zoom.system.request.app.common_packages,
+            zoom.system.request.app.packages,
+        ])
     for packages in packages_list:
         registered.update(packages)
     return registered
